@@ -36,6 +36,9 @@ typedef struct {
 	char *device;
 	char *physical;
 	char *address;
+	char *vendor;
+	char *model;
+	char *serial_nbr;
 } ArvInterfaceDeviceIds;
 
 #define ARV_TYPE_INTERFACE             (arv_interface_get_type ())
@@ -68,6 +71,9 @@ unsigned int 		arv_interface_get_n_devices 		(ArvInterface *interface);
 const char * 		arv_interface_get_device_id 		(ArvInterface *interface, unsigned int index);
 const char * 		arv_interface_get_device_physical_id 	(ArvInterface *interface, unsigned int index);
 const char * 		arv_interface_get_device_address	(ArvInterface *interface, unsigned int index);
+const char * 		arv_interface_get_device_vendor		(ArvInterface *interface, unsigned int index);
+const char * 		arv_interface_get_device_model		(ArvInterface *interface, unsigned int index);
+const char * 		arv_interface_get_device_serial_nbr		(ArvInterface *interface, unsigned int index);
 ArvDevice * 		arv_interface_open_device 		(ArvInterface *interface, const char *device_id);
 
 G_END_DECLS
