@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General
  * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Author: Emmanuel Pacaud <emmanuel@gnome.org>
  */
@@ -67,8 +67,10 @@ void 		arv_copy_memory_with_endianess 	(void *to, size_t to_size, guint to_endia
 
 void * 		arv_decompress 			(void *input_buffer, size_t input_size, size_t *output_size);
 
-const char * 	arv_pixel_format_to_gst_caps_string 	(ArvPixelFormat pixel_format);
-ArvPixelFormat 	arv_pixel_format_from_gst_caps 		(const char *name, int bpp, int depth, guint32 fourcc);
+const char * 	arv_pixel_format_to_gst_caps_string 		(ArvPixelFormat pixel_format);
+ArvPixelFormat 	arv_pixel_format_from_gst_caps 			(const char *name, const char *format);
+const char * 	arv_pixel_format_to_gst_0_10_caps_string 	(ArvPixelFormat pixel_format);
+ArvPixelFormat 	arv_pixel_format_from_gst_0_10_caps 		(const char *name, int bpp, int depth, guint32 fourcc);
 
 /*
    Compatibility with old glib
