@@ -24,7 +24,6 @@
 #define ARV_TYPES_H
 
 #include <arvenums.h>
-#include <arvconfig.h>
 
 G_BEGIN_DECLS
 
@@ -79,11 +78,9 @@ typedef struct _ArvGvInterface 		ArvGvInterface;
 typedef struct _ArvGvDevice 		ArvGvDevice;
 typedef struct _ArvGvStream 		ArvGvStream;
 
-#ifdef ARAVIS_BUILD_USB
 typedef struct _ArvUvInterface 		ArvUvInterface;
 typedef struct _ArvUvDevice		ArvUvDevice;
 typedef struct _ArvUvStream		ArvUvStream;
-#endif
 
 typedef struct _ArvFakeInterface	ArvFakeInterface;
 typedef struct _ArvFakeDevice		ArvFakeDevice;
