@@ -23,7 +23,7 @@ new_buffer_cb (ArvStream *stream, ApplicationData *data)
 
 	buffer = arv_stream_try_pop_buffer (stream);
 	if (buffer != NULL) {
-		if (buffer->status == ARV_BUFFER_STATUS_SUCCESS)
+		if (arv_buffer_get_status (buffer) == ARV_BUFFER_STATUS_SUCCESS)
 			data->buffer_count++;
 		/* Image processing here */
 		arv_stream_push_buffer (stream, buffer);
