@@ -138,9 +138,9 @@ int main(int argc, char *argv[])
 
 	    arv_stream_get_statistics (stream, &n_completed_buffers, &n_failures, &n_underruns);
 
-	    g_printf ("\nCompleted buffers = %Lu\n", (unsigned long long) n_completed_buffers);
-	    g_printf ("Failures          = %Lu\n", (unsigned long long) n_failures);
-	    g_printf ("Underruns         = %Lu\n", (unsigned long long) n_underruns);
+	    printf ("\nCompleted buffers = %Lu\n", (unsigned long long) n_completed_buffers);
+	    printf ("Failures          = %Lu\n", (unsigned long long) n_failures);
+	    printf ("Underruns         = %Lu\n", (unsigned long long) n_underruns);
 
 	    arv_camera_stop_acquisition (camera);
     }
